@@ -111,99 +111,4 @@ test_that("Input validates correctly ", {
   skip_on_cran()
   #expect_warning(IntegrateData(anchorset = anchors2, k.weight = 50, features = c(rownames(ref), "BAD")))
   #expect_warning(IntegrateData(anchorset = anchors2, k.weight = 50, dims = 1:1000))
-})
-
-# Tests for IntegrateLayers
-# ------------------------------------------------------------------------------
-context("IntegrateLayers")
-pbmc_small[['RNAv5']] <- CreateAssay5Object(counts = LayerData(pbmc_small[['RNA']], layer = "counts"))
-
-pbmc_small[["RNAv5"]] <- split(pbmc_small[["RNAv5"]], f = pbmc_small$groups)
-DefaultAssay(pbmc_small) <- "RNAv5"
-pbmc_small <- NormalizeData(pbmc_small)
-pbmc_small <- FindVariableFeatures(pbmc_small)
-pbmc_small <- ScaleData(pbmc_small)
-pbmc_small <- suppressMessages(suppressWarnings(RunPCA(pbmc_small)))
-
-
-test_that("IntegrateLayers does not work on a v3 assay ", {
-  expect_error(IntegrateLayers(object = pbmc_small, method = CCAIntegration,
-                               orig.reduction = "pca",
-                               assay = "RNA",
-                               new.reduction = "integrated.cca"))
-})
-
-test_that("IntegrateLayers errors out if incorrect input ", {
-  expect_error(IntegrateLayers(object = pbmc_small, method = CCAIntegration,
-                               orig.reduction = "pca",
-                               assay = "DNA",
-                               new.reduction = "integrated.cca"))
-  expect_error(IntegrateLayers(object = pbmc_small, method = CCAIntegration,
-                               orig.reduction = "lda",
-                               new.reduction = "integrated.cca"))
-})
-
-#itegration methods
-int_cca <- suppressMessages(suppressWarnings(IntegrateLayers(
-  object = pbmc_small, method = CCAIntegration,
-  orig.reduction = "pca", new.reduction = "integrated.cca",
-  k.weight=25,
-  verbose = FALSE
-)))
-int_rpca <- suppressMessages(suppressWarnings(IntegrateLayers(
-  object = pbmc_small, method = RPCAIntegration,
-  orig.reduction = "pca", new.reduction = "integrated.rpca",
-  dims = 1:10,
-  k.anchor = 10,
-  k.weight=10,
-  verbose = FALSE
-)))
-
-# int_mnn <- suppressMessages(suppressWarnings(IntegrateLayers(
-#   object = pbmc_small, method = FastMNNIntegration,
-#   new.reduction = "integrated.mnn",
-#   k.weight=25,
-#   verbose = FALSE
-# )))
-
-
-test_that("IntegrateLayers returns embeddings with correct dimensions ", {
-  expect_equal(dim(int_cca[["integrated.cca"]]), c(80, 50))
-  expect_equal(dim(int_rpca[["integrated.rpca"]]), c(80, 50))
-
-  int_rpca
-  expect_equal(int_cca[["integrated.cca"]]@assay.used, "RNAv5")
-  #expect_equal(int_cca[['integrated.cca']]@cell.embeddings, c(3, 4, 5))
-})
-
-test_that("IntegrateLayers works with harmony", {
-  skip_on_cran()
-  skip_if_not_installed("harmony")
-  int_harmony <- suppressMessages(suppressWarnings(IntegrateLayers(
-    object = pbmc_small, method = HarmonyIntegration,
-    orig.reduction = "pca", new.reduction = "harmony",
-    k.weight=25,
-    verbose = FALSE
-  )))
-  expect_equal(dim(int_harmony[["harmony"]]), c(80, 50))
-
-
-})
-
-test_that("group.by ", {
-  expect_equal(dim(int_cca[["integrated.cca"]]), c(80, 50))
-  expect_equal(int_cca[["integrated.cca"]]@assay.used, "RNAv5")
-})
-
-
-#Harmony integration
-# int_2 <- IntegrateLayers(object = pbmc_small, method = CCAIntegration,
-#                          group.by = "letter.idents",
-#                 orig.reduction = "pca",
-#                 assay = "RNAv5",
-#                 k.weight = 20,
-#                 new.reduction = "integrated.cca")
-#
-# head(int_2[['integrated.cca']]@cell.embeddings[1:5,1:5])
-# head(int_cca[['integrated.cca']]@cell.embeddings[1:5,1:5])
-
+})
\ No newline at end of file
